==> qucs-s-debug-24.4.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.4.0/builddir/qucsator_rf/src/parse_mdl.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_MDL_PARSE_MDL_HPP_INCLUDED
# define YY_MDL_PARSE_MDL_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int mdl_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    LINK = 258,                    /* LINK  */
    Identifier = 259,              /* Identifier  */
    String = 260,                  /* String  */
    InvalidCharacter = 261,        /* InvalidCharacter  */
    Real = 262,                    /* Real  */
    t_LINK = 263,                  /* t_LINK  */
    t_VIEW = 264,                  /* t_VIEW  */
    t_TABLE = 265,                 /* t_TABLE  */
    t_PSTABLE = 266,               /* t_PSTABLE  */
    t_CNTABLE = 267,               /* t_CNTABLE  */
    t_OPTIMEDIT = 268,             /* t_OPTIMEDIT  */
    t_BLKEDIT = 269,               /* t_BLKEDIT  */
    t_HYPTABLE = 270,              /* t_HYPTABLE  */
    t_ELEMENT = 271,               /* t_ELEMENT  */
    t_DATA = 272,                  /* t_DATA  */
    t_DATASET = 273,               /* t_DATASET  */
    t_DATASIZE = 274,              /* t_DATASIZE  */
    t_POINT = 275,                 /* t_POINT  */
    t_MEMBER = 276,                /* t_MEMBER  */
    t_LIST = 277,                  /* t_LIST  */
    t_PLOTOPTIMIZEROPT = 278,      /* t_PLOTOPTIMIZEROPT  */
    t_PLOTOPTIMIZERTRACESET = 279, /* t_PLOTOPTIMIZERTRACESET  */
    t_PLOTOPTIMIZERTRACEREGSET = 280, /* t_PLOTOPTIMIZERTRACEREGSET  */
    t_PLOTOPTIMIZERTRACENATREGSET = 281, /* t_PLOTOPTIMIZERTRACENATREGSET  */
    t_PLOTERROR = 282,             /* t_PLOTERROR  */
    t_TYPE = 283,                  /* t_TYPE  */
    t_CIRCUITDECK = 284,           /* t_CIRCUITDECK  */
    t_PARAM = 285,                 /* t_PARAM  */
    t_RANGE = 286,                 /* t_RANGE  */
    t_CONNPAIR = 287,              /* t_CONNPAIR  */
    t_CALDATA = 288,               /* t_CALDATA  */
    t_CALSET = 289,                /* t_CALSET  */
    t_TERM = 290,                  /* t_TERM  */
    t_APPLIC = 291,                /* t_APPLIC  */
    t_SUBAPP = 292,                /* t_SUBAPP  */
    t_EDITSIZE = 293,              /* t_EDITSIZE  */
    t_PLOTSIZE = 294,              /* t_PLOTSIZE  */
    t_OPTRANGE = 295               /* t_OPTRANGE  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 93 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_mdl.ypp"

  char * ident;
  double f;
  struct mdl_point_t * point;
  struct mdl_dataset_t * dset;
  struct mdl_datasize_t * dsize;
  struct mdl_link_t * link;
  struct mdl_data_t * data;
  struct mdl_dcontent_t * dcontent;
  struct mdl_lcontent_t * lcontent;
  struct mdl_element_t * element;
  struct mdl_hyptable_t * hyptable;
  struct mdl_table_t * table;

#line 119 "parse_mdl.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE mdl_lval;


int mdl_parse (void);


#endif /* !YY_MDL_PARSE_MDL_HPP_INCLUDED  */

==> qucs-s-debug-25.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-25.1.1/builddir/qucsator_rf/src/parse_mdl.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_MDL_PARSE_MDL_HPP_INCLUDED
# define YY_MDL_PARSE_MDL_HPP_INCLUDED
/* Debug traces.  */
#ifndef MDL_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define MDL_DEBUG 1
#  else
#   define MDL_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define MDL_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined MDL_DEBUG */
#if MDL_DEBUG
extern int mdl_debug;
#endif

/* Token kinds.  */
#ifndef MDL_TOKENTYPE
# define MDL_TOKENTYPE
  enum mdl_tokentype
  {
    MDL_EMPTY = -2,
    MDL_EOF = 0,                   /* "end of file"  */
    MDL_error = 256,               /* error  */
    MDL_UNDEF = 257,               /* "invalid token"  */
    LINK = 258,                    /* LINK  */
    Identifier = 259,              /* Identifier  */
    String = 260,                  /* String  */
    InvalidCharacter = 261,        /* InvalidCharacter  */
    Real = 262,                    /* Real  */
    t_LINK = 263,                  /* t_LINK  */
    t_VIEW = 264,                  /* t_VIEW  */
    t_TABLE = 265,                 /* t_TABLE  */
    t_PSTABLE = 266,               /* t_PSTABLE  */
    t_CNTABLE = 267,               /* t_CNTABLE  */
    t_OPTIMEDIT = 268,             /* t_OPTIMEDIT  */
    t_BLKEDIT = 269,               /* t_BLKEDIT  */
    t_HYPTABLE = 270,              /* t_HYPTABLE  */
    t_ELEMENT = 271,               /* t_ELEMENT  */
    t_DATA = 272,                  /* t_DATA  */
    t_DATASET = 273,               /* t_DATASET  */
    t_DATASIZE = 274,              /* t_DATASIZE  */
    t_POINT = 275,                 /* t_POINT  */
    t_MEMBER = 276,                /* t_MEMBER  */
    t_LIST = 277,                  /* t_LIST  */
    t_PLOTOPTIMIZEROPT = 278,      /* t_PLOTOPTIMIZEROPT  */
    t_PLOTOPTIMIZERTRACESET = 279, /* t_PLOTOPTIMIZERTRACESET  */
    t_PLOTOPTIMIZERTRACEREGSET = 280, /* t_PLOTOPTIMIZERTRACEREGSET  */
    t_PLOTOPTIMIZERTRACENATREGSET = 281, /* t_PLOTOPTIMIZERTRACENATREGSET  */
    t_PLOTERROR = 282,             /* t_PLOTERROR  */
    t_TYPE = 283,                  /* t_TYPE  */
    t_CIRCUITDECK = 284,           /* t_CIRCUITDECK  */
    t_PARAM = 285,                 /* t_PARAM  */
    t_RANGE = 286,                 /* t_RANGE  */
    t_CONNPAIR = 287,              /* t_CONNPAIR  */
    t_CALDATA = 288,               /* t_CALDATA  */
    t_CALSET = 289,                /* t_CALSET  */
    t_TERM = 290,                  /* t_TERM  */
    t_APPLIC = 291,                /* t_APPLIC  */
    t_SUBAPP = 292,                /* t_SUBAPP  */
    t_EDITSIZE = 293,              /* t_EDITSIZE  */
    t_PLOTSIZE = 294,              /* t_PLOTSIZE  */
    t_OPTRANGE = 295               /* t_OPTRANGE  */
  };
  typedef enum mdl_tokentype mdl_token_kind_t;
#endif

/* Value type.  */
#if ! defined MDL_STYPE && ! defined MDL_STYPE_IS_DECLARED
union MDL_STYPE
{
#line 93 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_mdl.ypp"

  char * ident;
  double f;
  struct mdl_point_t * point;
  struct mdl_dataset_t * dset;
  struct mdl_datasize_t * dsize;
  struct mdl_link_t * link;
  struct mdl_data_t * data;
  struct mdl_dcontent_t * dcontent;
  struct mdl_lcontent_t * lcontent;
  struct mdl_element_t * element;
  struct mdl_hyptable_t * hyptable;
  struct mdl_table_t * table;

#line 127 "parse_mdl.hpp"

};
typedef union MDL_STYPE MDL_STYPE;
# define MDL_STYPE_IS_TRIVIAL 1
# define MDL_STYPE_IS_DECLARED 1
#endif


extern MDL_STYPE mdl_lval;


int mdl_parse (void);


#endif /* !YY_MDL_PARSE_MDL_HPP_INCLUDED  */
